@@ -39,8 +39,8 @@ import random
 import socket
 import sys
 import time
+import traceback
 from io import open
-from subprocess import check_output
 
 from psutil import Process
 import zmq
@@ -51,7 +51,6 @@ from gridmap.data import clean_path, zloads, zdumps
 
 # TODO: Refactor this so that there's a class that stores socket, since creating
 #       a new one each time is hugely wasteful.
-
 def _send_zmq_msg(job_id, command, data, address):
     """
     simple code to send messages back to host
@@ -107,7 +106,7 @@ def get_memory_usage(pid):
     """
 
     p = Process(pid)
-    return p.get_memory_usage()[0] / (1024.0 ** 2.0)
+    return float(p.get_memory_usage()[0]) / (1024.0 ** 2.0)
 
 
 def get_cpu_load(pid):
@@ -121,7 +120,7 @@ def get_cpu_load(pid):
     """
 
     p = Process(pid)
-    return p.get_cpu_percent(), p.status
+    return float(p.get_cpu_percent()), p.status
 
 
 def get_job_status(parent_pid):
@@ -167,8 +166,10 @@ def _run_job(job_id, address):
         logger.error('Could not retrieve input for job {0}'.format(job_id),
                      exc_info=True)
 
-        # send back exception
-        thank_you_note = _send_zmq_msg(job_id, "store_output", e, address)
+        # send back exception and traceback string
+        thank_you_note = _send_zmq_msg(job_id, "store_output",
+                                       (e, traceback.format_exc()),
+                                       address)
         return
 
     logger.debug("input arguments loaded, starting computation %s", job)
